@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

/* Dont embolden the text on the selected tab */
tab[selected="true"] {
    font-weight: normal !important;
}

/* Shrink toolbars -> by about 2 pixels :-( ... */
/* Setting explicit heights, messes things up when text+icons is shown :-( */
#nav-bar {
    margin: 0px !important;
    padding: 1px !important;
    border: 0px !important;
}

.textbox-input-box,#identity-box,#urlbar-icons,.autocomplete-history-dropmarker,.searchbar-engine-button,.search-go-container,.box-inherit.button-box {
    margin: 0px !important;
    padding: 0px !important;
}

.searchbar-engine-button {
    margin: 0px !important;
    padding: 2px !important;
}
