@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

/* Swap Cancel/OK -> OK/Cancel */
.dialog-button-box { -moz-box-direction: reverse; -moz-box-pack: right; }
.dialog-button-box spacer { display: none !important; }
prefwindow { -moz-binding: url("file:///mozilla/preferences-rev.xml#prefwindow") !important; }
